@@ -1,4 +1,4 @@
-/* GStreamer
+/* GStreamer NUV demuxer
  * Copyright (C) <2006> Renato Araujo Oliveira Filho <renato.filho@indt.org.br>
  *                      Rosfran Borges <rosfran.borges@indt.org.br>
  *
@@ -21,24 +21,21 @@
 
 /**
  * SECTION:element-nuvdemux
+ * @see_also: mythtvsrc
  *
- * <refsect2>
- * <para>
- * Demuxes an .nuv file into raw or compressed audio and/or video streams.
- * </para>
- * <para>
+ * Demuxes MythTVs NuppelVideo .nuv file into raw or compressed audio and/or
+ * video streams.
+ * 
  * This element currently only supports pull-based scheduling.
- * </para>
+ * 
+ * <refsect2>
  * <title>Example launch line</title>
- * <para>
- * <programlisting>
+ * |[
  * gst-launch filesrc test.nuv ! nuvdemux name=demux  demux.audio_00 ! decodebin ! audioconvert ! audioresample ! autoaudiosink   demux.video_00 ! queue ! decodebin ! ffmpegcolorspace ! videoscale ! autovideosink
- * </programlisting>
- * Play (parse and decode) an .nuv file and try to output it to
+ * ]| Play (parse and decode) an .nuv file and try to output it to
  * an automatically detected soundcard and videosink. If the NUV file contains
  * compressed audio or video data, this will only work if you have the
  * right decoder elements/plugins installed.
- * </para>
  * </refsect2>
  *
  */
@@ -66,7 +63,7 @@ GST_DEBUG_CATEGORY_EXTERN (GST_CAT_EVENT);
 static const GstElementDetails gst_nuv_demux_details =
 GST_ELEMENT_DETAILS ("Nuv demuxer",
     "Codec/Demuxer",
-    "Demultiplex a .nuv file into audio and video",
+    "Demultiplex a mythtv .nuv file into audio and video",
     "Renato Araujo Oliveira Filho <renato.filho@indt.org.br>,"
     "Rosfran Borges <rosfran.borges@indt.org.br>");
 
@@ -151,13 +148,10 @@ gst_nuv_demux_class_init (GstNuvDemuxClass * klass)
   GstElementClass *gstelement_class = GST_ELEMENT_CLASS (klass);
   GObjectClass *gobject_class = (GObjectClass *) klass;
 
-  GST_DEBUG_CATEGORY_INIT (nuvdemux_debug, "nuvdemux",
-      0, "Demuxer for NUV streams");
-
-  parent_class = g_type_class_peek_parent (klass);
-
   gobject_class->finalize = gst_nuv_demux_finalize;
-  gstelement_class->change_state = gst_nuv_demux_change_state;
+
+  gstelement_class->change_state =
+      GST_DEBUG_FUNCPTR (gst_nuv_demux_change_state);
 }
 
 static void
@@ -203,7 +197,7 @@ gst_nuv_demux_finalize (GObject * object)
 }
 
 /*****************************************************************************
- * Utils fucntions
+ * Utils functions
  *****************************************************************************/
 
 static gboolean
@@ -231,12 +225,14 @@ static GstFlowReturn
 gst_nuv_demux_header_load (GstNuvDemux * nuv, nuv_header ** h_ret)
 {
   GstBuffer *buffer = NULL;
-  GstFlowReturn res = gst_nuv_demux_read_bytes (nuv, 72, TRUE, &buffer);
+  GstFlowReturn res;
+  nuv_header *h;
 
+  res = gst_nuv_demux_read_bytes (nuv, 72, TRUE, &buffer);
   if (res != GST_FLOW_OK)
     return res;
 
-  nuv_header *h = g_new0 (nuv_header, 1);
+  h = g_new0 (nuv_header, 1);
 
   memcpy (h->id, buffer->data, 12);
   memcpy (h->version, buffer->data + 12, 5);
@@ -622,9 +618,10 @@ gst_nuv_demux_stream_extend_header (GstNuvDemux * nuv)
   }
 
   if (buf->data[0] == 'X') {
+    nuv_frame_header *h = NULL;
+
     gst_buffer_unref (buf);
     buf = NULL;
-    nuv_frame_header *h = NULL;
 
     res = gst_nuv_demux_frame_header_load (nuv, &h);
     if (res != GST_FLOW_OK)
@@ -639,9 +636,9 @@ gst_nuv_demux_stream_extend_header (GstNuvDemux * nuv)
     nuv->state = GST_NUV_DEMUX_EXTEND_HEADER_DATA;
   } else {
     nuv->state = GST_NUV_DEMUX_INVALID_DATA;
+    GST_ELEMENT_ERROR (nuv, STREAM, DEMUX, (NULL),
+        ("Unsupported extended header (0x%02x)", buf->data[0]));
     g_object_unref (buf);
-    GST_ELEMENT_WARNING (nuv, STREAM, FAILED,
-        (_("incomplete NUV support")), ("incomplete NUV support"));
     return GST_FLOW_ERROR;
   }
   return res;
@@ -802,11 +799,16 @@ gst_nuv_demux_sink_activate (GstPad * sinkpad)
 
   if (gst_pad_check_pull_range (sinkpad)) {
     nuv->mode = 0;
-    nuv->adapter = NULL;
+    if (nuv->adapter != NULL) {
+      gst_object_unref (nuv->adapter);
+      nuv->adapter = NULL;
+    }
     res = gst_pad_activate_pull (sinkpad, TRUE);
   } else {
     nuv->mode = 1;
-    nuv->adapter = gst_adapter_new ();
+    if (!nuv->adapter) {
+      nuv->adapter = gst_adapter_new ();
+    }
     res = gst_pad_activate_push (sinkpad, TRUE);
   }
 
@@ -918,8 +920,12 @@ done:
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
+  GST_DEBUG_CATEGORY_INIT (nuvdemux_debug, "nuvdemux",
+      0, "Demuxer for NUV streams");
+
 #ifdef ENABLE_NLS
-  setlocale (LC_ALL, "");
+  GST_DEBUG ("binding text domain %s to locale dir %s", GETTEXT_PACKAGE,
+      LOCALEDIR);
   bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 #endif /* ENABLE_NLS */
 
@@ -934,4 +940,4 @@ GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
     GST_VERSION_MINOR,
     "nuvdemux",
     "Demuxes and muxes audio and video",
-    plugin_init, VERSION, "LGPL", "NuvDemux", "")
+    plugin_init, VERSION, GST_LICENSE, GST_PACKAGE_NAME, GST_PACKAGE_ORIGIN)
